@@ -39,7 +39,7 @@ class ImportFeedListCommand : public Command
     Q_OBJECT
 public:
     explicit ImportFeedListCommand(QObject *parent = nullptr);
-    ~ImportFeedListCommand();
+    ~ImportFeedListCommand() override;
 
     void setTargetList(const QWeakPointer<FeedList> &feedList);
 
@@ -61,7 +61,6 @@ private:
 private:
     class Private;
     Private *const d;
-    Q_PRIVATE_SLOT(d, void doImport())
 };
 }
 
